<?php
	abstract class Vue {
		/* array(<URL>, <Title>) */
		/* Page titles are passed through STR::html() */
		private $pages = array(array('Home', 'Home'),
							   array('Users', 'Users'));
		
		// To be implemented in child classes
		protected function authenticate() { return AUTH::IsLoggedIn(); }
		protected function authorize($post) { return true; }
		protected function handleGET() {}
		protected function handlePOST() {}
		abstract protected function render();
		
		final function handle() {
			if (!$this->authenticate())
				return (new Vue401())->handle();
			$method = $_SERVER['REQUEST_METHOD'];
			if (!$this->authorize($method === 'POST'))
				return (new Vue403())->handle();
			if ($method === 'GET')
				$this->handleGET();
			if ($method === 'POST')
				$this->handlePOST();
			$this->render();
		}
		
		final protected function renderTitle($title, $menu = true) {
			$user = AUTH::GetUser();
?>
<!doctype html>
<meta content=width=device-width name=viewport />
<link href="<?= URL::AppURLHTML('style', 'sheet.css') ?>" rel=stylesheet />
<title><?= htmlspecialchars($title) ?></title>
<form method=post><p><table width=100%><tr>
<?php if ($menu): ?>
	<td align=left>
<?php	if ($user): ?>
		<?= STR::html('Welcome') ?>, <span class=user><?= htmlspecialchars($user['fullname'] . ' (' . $user['name'] . ')') ?></span>.
		<br />
<?php	endif; ?>
<?php	foreach ($this->pages as list($page, $name)): ?>
<?php		if ($page === PAGE && !strlen(SUBPAGE) && !$_GET): ?>
		<a><?= STR::html($name) ?></a>
<?php		else: ?>
		<a href="<?= URL::FullURLHTML(...(array)$page) ?>"><?= STR::html($name) ?></a>
<?php		endif; ?>
<?php	endforeach; ?>
	</td>
<?php endif; ?>
	<td align=right nowrap>
<?php foreach (STR::langs() as $lang): ?>
<?php	if ($lang !== LANG): ?>
		<a href="<?= URL::LangURLHTML($lang) ?>"><?= STR::html($lang) ?></a>
<?php	endif; ?>
<?php endforeach; ?>
<?php if ($user): ?>
		<button name=_logout><?= STR::html('Logout') ?></button>
<?php endif; ?>
	</td>
</tr></table><p></form>
<hr />
<h1><?= htmlspecialchars($title) ?></h1>
<?php
		}
	}
?>
